summaryrefslogtreecommitdiffstats
path: root/generic/tclListObj.c
diff options
context:
space:
mode:
authordavygrvy <davygrvy@pobox.com>2003-12-24 04:18:18 (GMT)
committerdavygrvy <davygrvy@pobox.com>2003-12-24 04:18:18 (GMT)
commit5d224fb11538aa654ba2028f75e5ffa06df2c579 (patch)
treeeff546c6e792fecd4310f81379419c1d68d63c28 /generic/tclListObj.c
parentbdb55bff6176c625c664d4ea5a4ec5187839d7a8 (diff)
downloadtcl-5d224fb11538aa654ba2028f75e5ffa06df2c579.zip
tcl-5d224fb11538aa654ba2028f75e5ffa06df2c579.tar.gz
tcl-5d224fb11538aa654ba2028f75e5ffa06df2c579.tar.bz2
All uses of 'panic' (the macro) changed
to 'Tcl_Panic' (the function). The #define of panic in tcl.h clearly states it is deprecated in the comments. [Patch 865264]
Diffstat (limited to 'generic/tclListObj.c')
-rw-r--r--generic/tclListObj.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/generic/tclListObj.c b/generic/tclListObj.c
index 64c4182..c990045 100644
--- a/generic/tclListObj.c
+++ b/generic/tclListObj.c
@@ -11,7 +11,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclListObj.c,v 1.17 2003/11/01 01:28:04 dkf Exp $
+ * RCS: @(#) $Id: tclListObj.c,v 1.18 2003/12/24 04:18:20 davygrvy Exp $
*/
#include "tclInt.h"
@@ -355,7 +355,7 @@ Tcl_SetListObj(objPtr, objc, objv)
int i;
if (Tcl_IsShared(objPtr)) {
- panic("Tcl_SetListObj called with shared object");
+ Tcl_Panic("Tcl_SetListObj called with shared object");
}
/*
@@ -487,7 +487,7 @@ Tcl_ListObjAppendList(interp, listPtr, elemListPtr)
Tcl_Obj **objv;
if (Tcl_IsShared(listPtr)) {
- panic("Tcl_ListObjAppendList called with shared object");
+ Tcl_Panic("Tcl_ListObjAppendList called with shared object");
}
if (listPtr->typePtr != &tclListType) {
result = SetListFromAny(interp, listPtr);
@@ -549,7 +549,7 @@ Tcl_ListObjAppendElement(interp, listPtr, objPtr)
int numElems, numRequired;
if (Tcl_IsShared(listPtr)) {
- panic("Tcl_ListObjAppendElement called with shared object");
+ Tcl_Panic("Tcl_ListObjAppendElement called with shared object");
}
if (listPtr->typePtr != &tclListType) {
int result = SetListFromAny(interp, listPtr);
@@ -749,7 +749,7 @@ Tcl_ListObjReplace(interp, listPtr, first, count, objc, objv)
int start, shift, newMax, i, j, result;
if (Tcl_IsShared(listPtr)) {
- panic("Tcl_ListObjReplace called with shared object");
+ Tcl_Panic("Tcl_ListObjReplace called with shared object");
}
if (listPtr->typePtr != &tclListType) {
result = SetListFromAny(interp, listPtr);
@@ -1368,10 +1368,10 @@ TclLsetFlat(interp, listPtr, indexCount, indexArray, valuePtr)
*
* Side effects:
*
* Panics if listPtr designates a shared object. Otherwise, attempts
* to convert it to a list. Decrements the ref count of the object
* at the specified index within the list, replaces with the
* object designated by valuePtr, and increments the ref count
* of the replacement object.
*
* It is the caller's responsibility to invalidate the string
@@ -1399,7 +1399,7 @@ TclListObjSetElement(interp, listPtr, index, valuePtr)
/* Ensure that the listPtr parameter designates an unshared list */
if (Tcl_IsShared(listPtr)) {
- panic("Tcl_ListObjSetElement called with shared object");
+ Tcl_Panic("Tcl_ListObjSetElement called with shared object");
}
if (listPtr->typePtr != &tclListType) {
result = SetListFromAny(interp, listPtr);
@@ -1618,7 +1618,7 @@ SetListFromAny(interp, objPtr)
break;
}
if (i > estCount) {
- panic("SetListFromAny: bad size estimate for list");
+ Tcl_Panic("SetListFromAny: bad size estimate for list");
}
/*
@@ -1368,10 +1368,10 @@ TclLsetFlat(interp, listPtr, indexCount, indexArray, valuePtr)
* Side effects:
*
- * Panics if listPtr designates a shared object. Otherwise, attempts
- * to convert it to a list. Decrements the ref count of the object
- * at the specified index within the list, replaces with the
- * object designated by valuePtr, and increments the ref count
+ * Tcl_Panic if listPtr designates a shared object. Otherwise,
+ * attempts to convert it to a list. Decrements the ref count of
+ * the object at the specified index within the list, replaces with
+ * the object designated by valuePtr, and increments the ref count
* of the replacement object.
*